@@ -1,18 +1,18 @@
 #include <RcppArmadillo.h>
 #include "zicmodel.h"
 
-extern "C" SEXP zic_sample( SEXP _y, SEXP _X, 
-			    SEXP _a0, SEXP _b0, SEXP _gbeta0,  SEXP _hbeta0, SEXP _nubeta0, 
-			    SEXP _rbeta0, SEXP _sbeta0, SEXP _e0, SEXP _f0, 
-			    SEXP _c0, SEXP _d0, SEXP _gdelta0, SEXP _hdelta0, SEXP _nudelta0, 
-			    SEXP _rdelta0, SEXP _sdelta0,
-			    SEXP _svs0, SEXP _nburnin, SEXP _nmcmc, SEXP _nthin, SEXP _tune ) 
+extern "C" SEXP zic_sample( SEXP Sy, SEXP SX, 
+			    SEXP Sa0, SEXP Sb0, SEXP Sgbeta0,  SEXP Shbeta0, SEXP Snubeta0, 
+			    SEXP Srbeta0, SEXP Ssbeta0, SEXP Se0, SEXP Sf0, 
+			    SEXP Sc0, SEXP Sd0, SEXP Sgdelta0, SEXP Shdelta0, SEXP Snudelta0, 
+			    SEXP Srdelta0, SEXP Ssdelta0,
+			    SEXP Ssvs0, SEXP Snburnin, SEXP Snmcmc, SEXP Snthin, SEXP Stune ) 
 {
   try 
-     {
+    {
        // data matrices and dimensions
-       Rcpp::IntegerVector yR( _y );  
-       Rcpp::NumericMatrix XR( _X );  
+       Rcpp::IntegerVector yR( Sy );  
+       Rcpp::NumericMatrix XR( SX );  
        const int n = XR.nrow();
        const int k = XR.ncol() - 1;
        const ivec y( yR.begin(), yR.size(), false );
@@ -21,35 +21,35 @@ extern "C" SEXP zic_sample( SEXP _y, SEXP _X,
        // prior
        SpikeSlabPrior betaprior, deltaprior;
        
-       betaprior.Va = Rcpp::as<double>( _a0 );
-       betaprior.Vb = Rcpp::as<double>( _b0 );
-       betaprior.g  = Rcpp::as<double>( _gbeta0 );
-       betaprior.h  = Rcpp::as<double>( _hbeta0 );
-       betaprior.nu = Rcpp::as<double>( _nubeta0 );
-       betaprior.r  = Rcpp::as<double>( _rbeta0 );
-       betaprior.s  = Rcpp::as<double>( _sbeta0 );
-       betaprior.e   = Rcpp::as<double>( _e0 );
-       betaprior.f   = Rcpp::as<double>( _f0 );
-       betaprior.svs = Rcpp::as<bool>( _svs0 );
+       betaprior.Va = Rcpp::as<double>( Sa0 );
+       betaprior.Vb = Rcpp::as<double>( Sb0 );
+       betaprior.g  = Rcpp::as<double>( Sgbeta0 );
+       betaprior.h  = Rcpp::as<double>( Shbeta0 );
+       betaprior.nu = Rcpp::as<double>( Snubeta0 );
+       betaprior.r  = Rcpp::as<double>( Srbeta0 );
+       betaprior.s  = Rcpp::as<double>( Ssbeta0 );
+       betaprior.e   = Rcpp::as<double>( Se0 );
+       betaprior.f   = Rcpp::as<double>( Sf0 );
+       betaprior.svs = Rcpp::as<bool>( Ssvs0 );
        
-       deltaprior.Va   = Rcpp::as<double>( _c0 );
-       deltaprior.Vb   = Rcpp::as<double>( _d0 );
-       deltaprior.g    = Rcpp::as<double>( _gdelta0 );
-       deltaprior.h    = Rcpp::as<double>( _hdelta0 );
-       deltaprior.nu   = Rcpp::as<double>( _nudelta0 );
-       deltaprior.r    = Rcpp::as<double>( _rdelta0 );
-       deltaprior.s    = Rcpp::as<double>( _sdelta0 );
+       deltaprior.Va   = Rcpp::as<double>( Sc0 );
+       deltaprior.Vb   = Rcpp::as<double>( Sd0 );
+       deltaprior.g    = Rcpp::as<double>( Sgdelta0 );
+       deltaprior.h    = Rcpp::as<double>( Shdelta0 );
+       deltaprior.nu   = Rcpp::as<double>( Snudelta0 );
+       deltaprior.r    = Rcpp::as<double>( Srdelta0 );
+       deltaprior.s    = Rcpp::as<double>( Ssdelta0 );
        deltaprior.e    = -9.9;
        deltaprior.f    = -9.9;
-       deltaprior.svs  = Rcpp::as<bool>( _svs0 );
+       deltaprior.svs  = Rcpp::as<bool>( Ssvs0 );
        
        // mcmc iterations
-       const int nburnin = Rcpp::as<int>( _nburnin );
-       const int nmcmc = Rcpp::as<int>( _nmcmc );
-       const int nthin = Rcpp::as<int>( _nthin );
+       const int nburnin = Rcpp::as<int>( Snburnin );
+       const int nmcmc = Rcpp::as<int>( Snmcmc );
+       const int nthin = Rcpp::as<int>( Snthin );
 
        // tuning parameter
-       const double tune = Rcpp::as<double>( _tune );
+       const double tune = Rcpp::as<double>( Stune );
               
        // memories
        vec alphamem( nmcmc/nthin ), gammamem( nmcmc/nthin ), sigma2mem( nmcmc/nthin ), 
